#include "MainApplication.h"

MainApplication::MainApplication()
	:mLogger(),
	 mDatabaseManager()
{

}

MainApplication::~MainApplication()
{

}

void MainApplication::Initialize(const std::filesystem::path& workDir)
{
	mLogger = FileLogger::Create();
	mLogger->SetWorkDirectory(workDir.string());
	mLogger->Open();
	mLogger->LogLine("Launched");

	mDatabaseManager = DatabaseManager::Create();
	mDatabaseManager->CreateDatabase(workDir.string() + "/database.db");

	mNetworkManager = NetworkManager::Create();

	mAudioManager = AudioManager::Create();
}

void MainApplication::RunServer()
{
	mNetworkManager->RunHttpServer();
}

void MainApplication::PlayAudio()
{
	auto device = AudioDevice::Create();
	mAudioManager->GetAudioInterface()->OpenDevice(device);
	mAudioManager->GetAudioInterface()->Play(device);
}

void MainApplication::ShutDown()
{
	mLogger->Close();
	mDatabaseManager->OnShutDown();
	mNetworkManager->ShutDown();
}

std::shared_ptr<MainApplication> MainApplication::Create()
{
	return std::make_shared<MainApplication>();
}
